@@ -41,20 +41,61 @@
 typedef struct _CfgIncludeLevel CfgIncludeLevel;
 typedef struct _CfgTokenBlock CfgTokenBlock;
 
+/*
+ * YYLTYPE/YYSTYPE naming conventions
+ *
+ * We use multiple bison generated grammars (basically one for each plugin)
+ * with a single lexer and the same location/symbol types.  Earlier we could
+ * easily just define YYLTYPE and YYSTYPE here and all generated grammars
+ * and the lexer used it properly.  With the advent of the `api.prefix'
+ * option for the grammars (and the deprecation of the old `name-prefix'
+ * behaviors), we needed to complicate things somewhat.
+ *
+ * We have three contexts where we need to use proper type names:
+ *   - in our own code where we might need to use location information (e.g. YYLTYPE)
+ *   - in the generated lexer,
+ *   - in the generated grammars
+ *
+ * Our own code
+ * ============
+ * Because of the various #define/typedef games that generated code uses, I
+ * decided that our own code should not use the names YYLTYPE/YYSTYPE
+ * directly.  In those cases we use CFG_LTYPE and CFG_STYPE to indicate that
+ * these are types related to our configuration language.  None of the
+ * grammars use the "CFG_" prefix (and should not in the future either).
+ *
+ * The generated lexer
+ * ===================
+ *
+ * The lexer get these types by us #define-ing YYLTYPE/YYSTYPE to
+ * CFG_LTYPE/STYPE but only privately, e.g.  these definitions should not be
+ * published to the rest of the codebase.  We do this by defining these in
+ * implementation files and not in the headers.  This is because some of the
+ * code would try to #ifdef based on the existance of these macros.
+ *
+ * The generated grammars
+ * ======================
+ * The grammars each have an api.location.type and api.value.type options in
+ * their .y files, which use the names CFG_LTYPE and CFG_STYPE respectively.
+ * The generated code uses YYLTYPE and YYSTYPE internally (defined as
+ * macros), but because of the previous points this does not create a
+ * conflict.
+ */
+
 /* the location type to carry location information from the lexer to the grammar */
-#define YYLTYPE YYLTYPE
-typedef struct YYLTYPE
+
+typedef struct CFG_LTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
-  CfgIncludeLevel *level;
-} YYLTYPE;
-#define YYLTYPE_IS_TRIVIAL 1
+
+  const gchar *name;
+} CFG_LTYPE;
 
 /* symbol type that carries token related information to the grammar */
-typedef struct YYSTYPE
+typedef struct CFG_STYPE
 {
   /* one of LL_ types that indicates which field is being used */
   int type;
@@ -67,9 +108,7 @@ typedef struct YYSTYPE
     void *ptr;
     gpointer node;
   };
-} YYSTYPE;
-#define YYSTYPE_IS_TRIVIAL 1
-#define YYSTYPE_IS_DECLARED 1
+} CFG_STYPE;
 
 #define KWS_NORMAL        0
 #define KWS_OBSOLETE      1
@@ -92,11 +131,10 @@ struct _CfgIncludeLevel
 {
   enum
   {
+    CFGI_NONE,
     CFGI_FILE,
     CFGI_BUFFER,
   } include_type;
-  /* include file or block name */
-  gchar *name;
   union
   {
     struct
@@ -113,7 +151,11 @@ struct _CfgIncludeLevel
       gsize content_length;
     } buffer;
   };
-  YYLTYPE lloc;
+
+  /* this value indicates that @line was used which changed lloc relative to
+   * an actual file */
+  gboolean lloc_changed_by_at_line;
+  CFG_LTYPE lloc;
   struct yy_buffer_state *yybuf;
 };
 
@@ -139,11 +181,11 @@ struct _CfgLexer
   GString *token_pretext;
   GString *token_text;
   GlobalConfig *cfg;
-  gboolean non_pragma_seen:1, ignore_pragma:1;
+  guint ignore_pragma:1;
 };
 
 /* pattern buffer */
-void cfg_lexer_unput_token(CfgLexer *self, YYSTYPE *yylval);
+void cfg_lexer_unput_token(CfgLexer *self, CFG_STYPE *yylval);
 
 void cfg_lexer_start_block_state(CfgLexer *self, const gchar block_boundary[2]);
 
@@ -153,7 +195,7 @@ void cfg_lexer_append_char(CfgLexer *self, char c);
 /* keyword handling */
 void cfg_lexer_set_current_keywords(CfgLexer *self, CfgLexerKeyword *keywords);
 char *cfg_lexer_get_keyword_string(CfgLexer *self, int kw);
-int cfg_lexer_lookup_keyword(CfgLexer *self, YYSTYPE *yylval, YYLTYPE *yylloc, const char *token);
+int cfg_lexer_map_word_to_token(CfgLexer *self, CFG_STYPE *yylval, const CFG_LTYPE *yylloc, const char *token);
 
 /* include files */
 gboolean cfg_lexer_start_next_include(CfgLexer *self);
@@ -161,8 +203,9 @@ gboolean cfg_lexer_include_file(CfgLexer *self, const gchar *filename);
 gboolean cfg_lexer_include_buffer(CfgLexer *self, const gchar *name, const gchar *buffer, gssize length);
 gboolean cfg_lexer_include_buffer_without_backtick_substitution(CfgLexer *self,
     const gchar *name, const gchar *buffer, gsize length);
-const gchar *cfg_lexer_format_location(CfgLexer *self, YYLTYPE *yylloc, gchar *buf, gsize buf_len);
-EVTTAG *cfg_lexer_format_location_tag(CfgLexer *self, YYLTYPE *yylloc);
+const gchar *cfg_lexer_format_location(CfgLexer *self, const CFG_LTYPE *yylloc, gchar *buf, gsize buf_len);
+void cfg_lexer_set_file_location(CfgLexer *self, const gchar *filename, gint line, gint column);
+EVTTAG *cfg_lexer_format_location_tag(CfgLexer *self, const CFG_LTYPE *yylloc);
 
 /* context tracking */
 void cfg_lexer_push_context(CfgLexer *self, gint context, CfgLexerKeyword *keywords, const gchar *desc);
@@ -173,10 +216,10 @@ gint cfg_lexer_get_context_type(CfgLexer *self);
 /* token blocks */
 void cfg_lexer_inject_token_block(CfgLexer *self, CfgTokenBlock *block);
 
-int cfg_lexer_lex(CfgLexer *self, YYSTYPE *yylval, YYLTYPE *yylloc);
-void cfg_lexer_free_token(YYSTYPE *token);
+int cfg_lexer_lex(CfgLexer *self, CFG_STYPE *yylval, CFG_LTYPE *yylloc);
+void cfg_lexer_free_token(CFG_STYPE *token);
 
-CfgLexer *cfg_lexer_new(GlobalConfig *cfg, const gchar *filename, GString *buffer, GString *preprocess_output);
+CfgLexer *cfg_lexer_new(GlobalConfig *cfg, FILE *file, const gchar *filename, GString *preprocess_output);
 CfgLexer *cfg_lexer_new_buffer(GlobalConfig *cfg, const gchar *buffer, gsize length);
 void  cfg_lexer_free(CfgLexer *self);
 
@@ -185,9 +228,9 @@ const gchar *cfg_lexer_lookup_context_name_by_type(gint id);
 
 /* token block objects */
 
-void cfg_token_block_add_and_consume_token(CfgTokenBlock *self, YYSTYPE *token);
-void cfg_token_block_add_token(CfgTokenBlock *self, YYSTYPE *token);
-YYSTYPE *cfg_token_block_get_token(CfgTokenBlock *self);
+void cfg_token_block_add_and_consume_token(CfgTokenBlock *self, CFG_STYPE *token);
+void cfg_token_block_add_token(CfgTokenBlock *self, CFG_STYPE *token);
+CFG_STYPE *cfg_token_block_get_token(CfgTokenBlock *self);
 
 CfgTokenBlock *cfg_token_block_new(void);
 void cfg_token_block_free(CfgTokenBlock *self);
